from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.sync_combined_search_body_company_params_last_funding_usd_type_0 import SyncCombinedSearchBodyCompanyParamsLastFundingUSDType0
  from ..models.sync_combined_search_body_company_params_headquarters_country_code_type_0 import SyncCombinedSearchBodyCompanyParamsHeadquartersCountryCodeType0
  from ..models.sync_combined_search_body_company_params_employee_trends_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0
  from ..models.sync_combined_search_body_company_params_num_words_in_name_type_0 import SyncCombinedSearchBodyCompanyParamsNumWordsInNameType0
  from ..models.sync_combined_search_body_company_params_naics_codes_type_0 import SyncCombinedSearchBodyCompanyParamsNaicsCodesType0
  from ..models.sync_combined_search_body_company_params_tlds_type_0 import SyncCombinedSearchBodyCompanyParamsTldsType0
  from ..models.sync_combined_search_body_company_params_founded_on_type_1 import SyncCombinedSearchBodyCompanyParamsFoundedOnType1
  from ..models.sync_combined_search_body_company_params_name_like_type_0 import SyncCombinedSearchBodyCompanyParamsNameLikeType0
  from ..models.sync_combined_search_body_company_params_revenue_usd_type_0 import SyncCombinedSearchBodyCompanyParamsRevenueUSDType0
  from ..models.sync_combined_search_body_company_params_status_type_0 import SyncCombinedSearchBodyCompanyParamsStatusType0
  from ..models.sync_combined_search_body_company_params_fortune_rankings_type_0 import SyncCombinedSearchBodyCompanyParamsFortuneRankingsType0
  from ..models.sync_combined_search_body_company_params_exact_company_v2_type_0 import SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0
  from ..models.sync_combined_search_body_company_params_industries_v2_type_0 import SyncCombinedSearchBodyCompanyParamsIndustriesV2Type0
  from ..models.sync_combined_search_body_company_params_keywords_type_0 import SyncCombinedSearchBodyCompanyParamsKeywordsType0
  from ..models.sync_combined_search_body_company_params_exact_company_type_0 import SyncCombinedSearchBodyCompanyParamsExactCompanyType0
  from ..models.sync_combined_search_body_company_params_special_flags_type_0 import SyncCombinedSearchBodyCompanyParamsSpecialFlagsType0
  from ..models.sync_combined_search_body_company_params_accelerators_v2_type_0 import SyncCombinedSearchBodyCompanyParamsAcceleratorsV2Type0
  from ..models.sync_combined_search_body_company_params_tags_type_0 import SyncCombinedSearchBodyCompanyParamsTagsType0
  from ..models.sync_combined_search_body_company_params_investors_type_0 import SyncCombinedSearchBodyCompanyParamsInvestorsType0
  from ..models.sync_combined_search_body_company_params_founded_on_type_0 import SyncCombinedSearchBodyCompanyParamsFoundedOnType0
  from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0
  from ..models.sync_combined_search_body_company_params_total_funding_usd_type_0 import SyncCombinedSearchBodyCompanyParamsTotalFundingUSDType0
  from ..models.sync_combined_search_body_company_params_headquarters_state_name_type_0 import SyncCombinedSearchBodyCompanyParamsHeadquartersStateNameType0
  from ..models.sync_combined_search_body_company_params_crunchbase_categories_type_0 import SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoriesType0
  from ..models.sync_combined_search_body_company_params_employee_count_v2_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0
  from ..models.sync_combined_search_body_company_params_employees_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeesType0
  from ..models.sync_combined_search_body_company_params_crunchbase_category_groups_type_0 import SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoryGroupsType0
  from ..models.sync_combined_search_body_company_params_job_posting_stats_type_0 import SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0
  from ..models.sync_combined_search_body_company_params_last_funded_on_type_0 import SyncCombinedSearchBodyCompanyParamsLastFundedOnType0
  from ..models.sync_combined_search_body_company_params_technologies_type_0 import SyncCombinedSearchBodyCompanyParamsTechnologiesType0
  from ..models.sync_combined_search_body_company_params_stage_type_0 import SyncCombinedSearchBodyCompanyParamsStageType0
  from ..models.sync_combined_search_body_company_params_office_locations_v2_type_0 import SyncCombinedSearchBodyCompanyParamsOfficeLocationsV2Type0
  from ..models.sync_combined_search_body_company_params_headquarters_location_type_0 import SyncCombinedSearchBodyCompanyParamsHeadquartersLocationType0
  from ..models.sync_combined_search_body_company_params_linkedin_industries_type_0 import SyncCombinedSearchBodyCompanyParamsLinkedinIndustriesType0
  from ..models.sync_combined_search_body_company_params_last_funded_on_type_1 import SyncCombinedSearchBodyCompanyParamsLastFundedOnType1





T = TypeVar("T", bound="SyncCombinedSearchBodyCompanyParams")



@_attrs_define
class SyncCombinedSearchBodyCompanyParams:
    """ Company search params. We would find prospects who are currently working in the companies that satisfy these search
    params. Make sure that the search scope of companies is small, else we truncate it to the top 1000 companies.

        Attributes:
            exact_company_v2 (Union['SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0', None, Unset]):
            domains (Union[None, Unset, list[str]]):
            headquarters_country_code (Union['SyncCombinedSearchBodyCompanyParamsHeadquartersCountryCodeType0', None,
                Unset]):
            headquarters_state_name (Union['SyncCombinedSearchBodyCompanyParamsHeadquartersStateNameType0', None, Unset]):
            employee_count_v2 (Union['SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0', None, Unset]):
            keywords (Union['SyncCombinedSearchBodyCompanyParamsKeywordsType0', None, Unset]):
            industries_v2 (Union['SyncCombinedSearchBodyCompanyParamsIndustriesV2Type0', None, Unset]):
            stage (Union['SyncCombinedSearchBodyCompanyParamsStageType0', None, Unset]):
            total_funding_usd (Union['SyncCombinedSearchBodyCompanyParamsTotalFundingUSDType0', None, Unset]):
            last_funding_usd (Union['SyncCombinedSearchBodyCompanyParamsLastFundingUSDType0', None, Unset]):
            last_funded_on (Union['SyncCombinedSearchBodyCompanyParamsLastFundedOnType0',
                'SyncCombinedSearchBodyCompanyParamsLastFundedOnType1', None, Unset]):
            founded_on (Union['SyncCombinedSearchBodyCompanyParamsFoundedOnType0',
                'SyncCombinedSearchBodyCompanyParamsFoundedOnType1', None, Unset]):
            name_like (Union['SyncCombinedSearchBodyCompanyParamsNameLikeType0', None, Unset]):
            exact_company (Union['SyncCombinedSearchBodyCompanyParamsExactCompanyType0', None, Unset]):
            accelerators_v2 (Union['SyncCombinedSearchBodyCompanyParamsAcceleratorsV2Type0', None, Unset]):
            employee_trends (Union['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0', None, Unset]):
            headquarters_location (Union['SyncCombinedSearchBodyCompanyParamsHeadquartersLocationType0', None, Unset]):
            linkedin_slugs (Union[None, Unset, list[str]]):
            special_flags (Union['SyncCombinedSearchBodyCompanyParamsSpecialFlagsType0', None, Unset]):
            employees (Union['SyncCombinedSearchBodyCompanyParamsEmployeesType0', None, Unset]):
            revenue_usd (Union['SyncCombinedSearchBodyCompanyParamsRevenueUSDType0', None, Unset]):
            naics_codes (Union['SyncCombinedSearchBodyCompanyParamsNaicsCodesType0', None, Unset]):
            fortune_rankings (Union['SyncCombinedSearchBodyCompanyParamsFortuneRankingsType0', None, Unset]):
            job_postings_v2 (Union['SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0', None, Unset]):
            job_posting_stats (Union['SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0', None, Unset]):
            office_locations_v2 (Union['SyncCombinedSearchBodyCompanyParamsOfficeLocationsV2Type0', None, Unset]):
            tlds (Union['SyncCombinedSearchBodyCompanyParamsTldsType0', None, Unset]):
            num_words_in_name (Union['SyncCombinedSearchBodyCompanyParamsNumWordsInNameType0', None, Unset]):
            status (Union['SyncCombinedSearchBodyCompanyParamsStatusType0', None, Unset]):
            technologies (Union['SyncCombinedSearchBodyCompanyParamsTechnologiesType0', None, Unset]):
            investors (Union['SyncCombinedSearchBodyCompanyParamsInvestorsType0', None, Unset]):
            tags (Union['SyncCombinedSearchBodyCompanyParamsTagsType0', None, Unset]):
            crunchbase_categories (Union['SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoriesType0', None, Unset]):
            crunchbase_category_groups (Union['SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoryGroupsType0', None,
                Unset]):
            linkedin_industries (Union['SyncCombinedSearchBodyCompanyParamsLinkedinIndustriesType0', None, Unset]):
            crunchbase_slugs (Union[None, Unset, list[str]]):
     """

    exact_company_v2: Union['SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0', None, Unset] = UNSET
    domains: Union[None, Unset, list[str]] = UNSET
    headquarters_country_code: Union['SyncCombinedSearchBodyCompanyParamsHeadquartersCountryCodeType0', None, Unset] = UNSET
    headquarters_state_name: Union['SyncCombinedSearchBodyCompanyParamsHeadquartersStateNameType0', None, Unset] = UNSET
    employee_count_v2: Union['SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0', None, Unset] = UNSET
    keywords: Union['SyncCombinedSearchBodyCompanyParamsKeywordsType0', None, Unset] = UNSET
    industries_v2: Union['SyncCombinedSearchBodyCompanyParamsIndustriesV2Type0', None, Unset] = UNSET
    stage: Union['SyncCombinedSearchBodyCompanyParamsStageType0', None, Unset] = UNSET
    total_funding_usd: Union['SyncCombinedSearchBodyCompanyParamsTotalFundingUSDType0', None, Unset] = UNSET
    last_funding_usd: Union['SyncCombinedSearchBodyCompanyParamsLastFundingUSDType0', None, Unset] = UNSET
    last_funded_on: Union['SyncCombinedSearchBodyCompanyParamsLastFundedOnType0', 'SyncCombinedSearchBodyCompanyParamsLastFundedOnType1', None, Unset] = UNSET
    founded_on: Union['SyncCombinedSearchBodyCompanyParamsFoundedOnType0', 'SyncCombinedSearchBodyCompanyParamsFoundedOnType1', None, Unset] = UNSET
    name_like: Union['SyncCombinedSearchBodyCompanyParamsNameLikeType0', None, Unset] = UNSET
    exact_company: Union['SyncCombinedSearchBodyCompanyParamsExactCompanyType0', None, Unset] = UNSET
    accelerators_v2: Union['SyncCombinedSearchBodyCompanyParamsAcceleratorsV2Type0', None, Unset] = UNSET
    employee_trends: Union['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0', None, Unset] = UNSET
    headquarters_location: Union['SyncCombinedSearchBodyCompanyParamsHeadquartersLocationType0', None, Unset] = UNSET
    linkedin_slugs: Union[None, Unset, list[str]] = UNSET
    special_flags: Union['SyncCombinedSearchBodyCompanyParamsSpecialFlagsType0', None, Unset] = UNSET
    employees: Union['SyncCombinedSearchBodyCompanyParamsEmployeesType0', None, Unset] = UNSET
    revenue_usd: Union['SyncCombinedSearchBodyCompanyParamsRevenueUSDType0', None, Unset] = UNSET
    naics_codes: Union['SyncCombinedSearchBodyCompanyParamsNaicsCodesType0', None, Unset] = UNSET
    fortune_rankings: Union['SyncCombinedSearchBodyCompanyParamsFortuneRankingsType0', None, Unset] = UNSET
    job_postings_v2: Union['SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0', None, Unset] = UNSET
    job_posting_stats: Union['SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0', None, Unset] = UNSET
    office_locations_v2: Union['SyncCombinedSearchBodyCompanyParamsOfficeLocationsV2Type0', None, Unset] = UNSET
    tlds: Union['SyncCombinedSearchBodyCompanyParamsTldsType0', None, Unset] = UNSET
    num_words_in_name: Union['SyncCombinedSearchBodyCompanyParamsNumWordsInNameType0', None, Unset] = UNSET
    status: Union['SyncCombinedSearchBodyCompanyParamsStatusType0', None, Unset] = UNSET
    technologies: Union['SyncCombinedSearchBodyCompanyParamsTechnologiesType0', None, Unset] = UNSET
    investors: Union['SyncCombinedSearchBodyCompanyParamsInvestorsType0', None, Unset] = UNSET
    tags: Union['SyncCombinedSearchBodyCompanyParamsTagsType0', None, Unset] = UNSET
    crunchbase_categories: Union['SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoriesType0', None, Unset] = UNSET
    crunchbase_category_groups: Union['SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoryGroupsType0', None, Unset] = UNSET
    linkedin_industries: Union['SyncCombinedSearchBodyCompanyParamsLinkedinIndustriesType0', None, Unset] = UNSET
    crunchbase_slugs: Union[None, Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.sync_combined_search_body_company_params_last_funding_usd_type_0 import SyncCombinedSearchBodyCompanyParamsLastFundingUSDType0
        from ..models.sync_combined_search_body_company_params_headquarters_country_code_type_0 import SyncCombinedSearchBodyCompanyParamsHeadquartersCountryCodeType0
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0
        from ..models.sync_combined_search_body_company_params_num_words_in_name_type_0 import SyncCombinedSearchBodyCompanyParamsNumWordsInNameType0
        from ..models.sync_combined_search_body_company_params_naics_codes_type_0 import SyncCombinedSearchBodyCompanyParamsNaicsCodesType0
        from ..models.sync_combined_search_body_company_params_tlds_type_0 import SyncCombinedSearchBodyCompanyParamsTldsType0
        from ..models.sync_combined_search_body_company_params_founded_on_type_1 import SyncCombinedSearchBodyCompanyParamsFoundedOnType1
        from ..models.sync_combined_search_body_company_params_name_like_type_0 import SyncCombinedSearchBodyCompanyParamsNameLikeType0
        from ..models.sync_combined_search_body_company_params_revenue_usd_type_0 import SyncCombinedSearchBodyCompanyParamsRevenueUSDType0
        from ..models.sync_combined_search_body_company_params_status_type_0 import SyncCombinedSearchBodyCompanyParamsStatusType0
        from ..models.sync_combined_search_body_company_params_fortune_rankings_type_0 import SyncCombinedSearchBodyCompanyParamsFortuneRankingsType0
        from ..models.sync_combined_search_body_company_params_exact_company_v2_type_0 import SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0
        from ..models.sync_combined_search_body_company_params_industries_v2_type_0 import SyncCombinedSearchBodyCompanyParamsIndustriesV2Type0
        from ..models.sync_combined_search_body_company_params_keywords_type_0 import SyncCombinedSearchBodyCompanyParamsKeywordsType0
        from ..models.sync_combined_search_body_company_params_exact_company_type_0 import SyncCombinedSearchBodyCompanyParamsExactCompanyType0
        from ..models.sync_combined_search_body_company_params_special_flags_type_0 import SyncCombinedSearchBodyCompanyParamsSpecialFlagsType0
        from ..models.sync_combined_search_body_company_params_accelerators_v2_type_0 import SyncCombinedSearchBodyCompanyParamsAcceleratorsV2Type0
        from ..models.sync_combined_search_body_company_params_tags_type_0 import SyncCombinedSearchBodyCompanyParamsTagsType0
        from ..models.sync_combined_search_body_company_params_investors_type_0 import SyncCombinedSearchBodyCompanyParamsInvestorsType0
        from ..models.sync_combined_search_body_company_params_founded_on_type_0 import SyncCombinedSearchBodyCompanyParamsFoundedOnType0
        from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0
        from ..models.sync_combined_search_body_company_params_total_funding_usd_type_0 import SyncCombinedSearchBodyCompanyParamsTotalFundingUSDType0
        from ..models.sync_combined_search_body_company_params_headquarters_state_name_type_0 import SyncCombinedSearchBodyCompanyParamsHeadquartersStateNameType0
        from ..models.sync_combined_search_body_company_params_crunchbase_categories_type_0 import SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoriesType0
        from ..models.sync_combined_search_body_company_params_employee_count_v2_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0
        from ..models.sync_combined_search_body_company_params_employees_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeesType0
        from ..models.sync_combined_search_body_company_params_crunchbase_category_groups_type_0 import SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoryGroupsType0
        from ..models.sync_combined_search_body_company_params_job_posting_stats_type_0 import SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0
        from ..models.sync_combined_search_body_company_params_last_funded_on_type_0 import SyncCombinedSearchBodyCompanyParamsLastFundedOnType0
        from ..models.sync_combined_search_body_company_params_technologies_type_0 import SyncCombinedSearchBodyCompanyParamsTechnologiesType0
        from ..models.sync_combined_search_body_company_params_stage_type_0 import SyncCombinedSearchBodyCompanyParamsStageType0
        from ..models.sync_combined_search_body_company_params_office_locations_v2_type_0 import SyncCombinedSearchBodyCompanyParamsOfficeLocationsV2Type0
        from ..models.sync_combined_search_body_company_params_headquarters_location_type_0 import SyncCombinedSearchBodyCompanyParamsHeadquartersLocationType0
        from ..models.sync_combined_search_body_company_params_linkedin_industries_type_0 import SyncCombinedSearchBodyCompanyParamsLinkedinIndustriesType0
        from ..models.sync_combined_search_body_company_params_last_funded_on_type_1 import SyncCombinedSearchBodyCompanyParamsLastFundedOnType1
        exact_company_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.exact_company_v2, Unset):
            exact_company_v2 = UNSET
        elif isinstance(self.exact_company_v2, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0):
            exact_company_v2 = self.exact_company_v2.to_dict()
        else:
            exact_company_v2 = self.exact_company_v2

        domains: Union[None, Unset, list[str]]
        if isinstance(self.domains, Unset):
            domains = UNSET
        elif isinstance(self.domains, list):
            domains = self.domains


        else:
            domains = self.domains

        headquarters_country_code: Union[None, Unset, dict[str, Any]]
        if isinstance(self.headquarters_country_code, Unset):
            headquarters_country_code = UNSET
        elif isinstance(self.headquarters_country_code, SyncCombinedSearchBodyCompanyParamsHeadquartersCountryCodeType0):
            headquarters_country_code = self.headquarters_country_code.to_dict()
        else:
            headquarters_country_code = self.headquarters_country_code

        headquarters_state_name: Union[None, Unset, dict[str, Any]]
        if isinstance(self.headquarters_state_name, Unset):
            headquarters_state_name = UNSET
        elif isinstance(self.headquarters_state_name, SyncCombinedSearchBodyCompanyParamsHeadquartersStateNameType0):
            headquarters_state_name = self.headquarters_state_name.to_dict()
        else:
            headquarters_state_name = self.headquarters_state_name

        employee_count_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.employee_count_v2, Unset):
            employee_count_v2 = UNSET
        elif isinstance(self.employee_count_v2, SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0):
            employee_count_v2 = self.employee_count_v2.to_dict()
        else:
            employee_count_v2 = self.employee_count_v2

        keywords: Union[None, Unset, dict[str, Any]]
        if isinstance(self.keywords, Unset):
            keywords = UNSET
        elif isinstance(self.keywords, SyncCombinedSearchBodyCompanyParamsKeywordsType0):
            keywords = self.keywords.to_dict()
        else:
            keywords = self.keywords

        industries_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.industries_v2, Unset):
            industries_v2 = UNSET
        elif isinstance(self.industries_v2, SyncCombinedSearchBodyCompanyParamsIndustriesV2Type0):
            industries_v2 = self.industries_v2.to_dict()
        else:
            industries_v2 = self.industries_v2

        stage: Union[None, Unset, dict[str, Any]]
        if isinstance(self.stage, Unset):
            stage = UNSET
        elif isinstance(self.stage, SyncCombinedSearchBodyCompanyParamsStageType0):
            stage = self.stage.to_dict()
        else:
            stage = self.stage

        total_funding_usd: Union[None, Unset, dict[str, Any]]
        if isinstance(self.total_funding_usd, Unset):
            total_funding_usd = UNSET
        elif isinstance(self.total_funding_usd, SyncCombinedSearchBodyCompanyParamsTotalFundingUSDType0):
            total_funding_usd = self.total_funding_usd.to_dict()
        else:
            total_funding_usd = self.total_funding_usd

        last_funding_usd: Union[None, Unset, dict[str, Any]]
        if isinstance(self.last_funding_usd, Unset):
            last_funding_usd = UNSET
        elif isinstance(self.last_funding_usd, SyncCombinedSearchBodyCompanyParamsLastFundingUSDType0):
            last_funding_usd = self.last_funding_usd.to_dict()
        else:
            last_funding_usd = self.last_funding_usd

        last_funded_on: Union[None, Unset, dict[str, Any]]
        if isinstance(self.last_funded_on, Unset):
            last_funded_on = UNSET
        elif isinstance(self.last_funded_on, SyncCombinedSearchBodyCompanyParamsLastFundedOnType0):
            last_funded_on = self.last_funded_on.to_dict()
        elif isinstance(self.last_funded_on, SyncCombinedSearchBodyCompanyParamsLastFundedOnType1):
            last_funded_on = self.last_funded_on.to_dict()
        else:
            last_funded_on = self.last_funded_on

        founded_on: Union[None, Unset, dict[str, Any]]
        if isinstance(self.founded_on, Unset):
            founded_on = UNSET
        elif isinstance(self.founded_on, SyncCombinedSearchBodyCompanyParamsFoundedOnType0):
            founded_on = self.founded_on.to_dict()
        elif isinstance(self.founded_on, SyncCombinedSearchBodyCompanyParamsFoundedOnType1):
            founded_on = self.founded_on.to_dict()
        else:
            founded_on = self.founded_on

        name_like: Union[None, Unset, dict[str, Any]]
        if isinstance(self.name_like, Unset):
            name_like = UNSET
        elif isinstance(self.name_like, SyncCombinedSearchBodyCompanyParamsNameLikeType0):
            name_like = self.name_like.to_dict()
        else:
            name_like = self.name_like

        exact_company: Union[None, Unset, dict[str, Any]]
        if isinstance(self.exact_company, Unset):
            exact_company = UNSET
        elif isinstance(self.exact_company, SyncCombinedSearchBodyCompanyParamsExactCompanyType0):
            exact_company = self.exact_company.to_dict()
        else:
            exact_company = self.exact_company

        accelerators_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.accelerators_v2, Unset):
            accelerators_v2 = UNSET
        elif isinstance(self.accelerators_v2, SyncCombinedSearchBodyCompanyParamsAcceleratorsV2Type0):
            accelerators_v2 = self.accelerators_v2.to_dict()
        else:
            accelerators_v2 = self.accelerators_v2

        employee_trends: Union[None, Unset, dict[str, Any]]
        if isinstance(self.employee_trends, Unset):
            employee_trends = UNSET
        elif isinstance(self.employee_trends, SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0):
            employee_trends = self.employee_trends.to_dict()
        else:
            employee_trends = self.employee_trends

        headquarters_location: Union[None, Unset, dict[str, Any]]
        if isinstance(self.headquarters_location, Unset):
            headquarters_location = UNSET
        elif isinstance(self.headquarters_location, SyncCombinedSearchBodyCompanyParamsHeadquartersLocationType0):
            headquarters_location = self.headquarters_location.to_dict()
        else:
            headquarters_location = self.headquarters_location

        linkedin_slugs: Union[None, Unset, list[str]]
        if isinstance(self.linkedin_slugs, Unset):
            linkedin_slugs = UNSET
        elif isinstance(self.linkedin_slugs, list):
            linkedin_slugs = self.linkedin_slugs


        else:
            linkedin_slugs = self.linkedin_slugs

        special_flags: Union[None, Unset, dict[str, Any]]
        if isinstance(self.special_flags, Unset):
            special_flags = UNSET
        elif isinstance(self.special_flags, SyncCombinedSearchBodyCompanyParamsSpecialFlagsType0):
            special_flags = self.special_flags.to_dict()
        else:
            special_flags = self.special_flags

        employees: Union[None, Unset, dict[str, Any]]
        if isinstance(self.employees, Unset):
            employees = UNSET
        elif isinstance(self.employees, SyncCombinedSearchBodyCompanyParamsEmployeesType0):
            employees = self.employees.to_dict()
        else:
            employees = self.employees

        revenue_usd: Union[None, Unset, dict[str, Any]]
        if isinstance(self.revenue_usd, Unset):
            revenue_usd = UNSET
        elif isinstance(self.revenue_usd, SyncCombinedSearchBodyCompanyParamsRevenueUSDType0):
            revenue_usd = self.revenue_usd.to_dict()
        else:
            revenue_usd = self.revenue_usd

        naics_codes: Union[None, Unset, dict[str, Any]]
        if isinstance(self.naics_codes, Unset):
            naics_codes = UNSET
        elif isinstance(self.naics_codes, SyncCombinedSearchBodyCompanyParamsNaicsCodesType0):
            naics_codes = self.naics_codes.to_dict()
        else:
            naics_codes = self.naics_codes

        fortune_rankings: Union[None, Unset, dict[str, Any]]
        if isinstance(self.fortune_rankings, Unset):
            fortune_rankings = UNSET
        elif isinstance(self.fortune_rankings, SyncCombinedSearchBodyCompanyParamsFortuneRankingsType0):
            fortune_rankings = self.fortune_rankings.to_dict()
        else:
            fortune_rankings = self.fortune_rankings

        job_postings_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.job_postings_v2, Unset):
            job_postings_v2 = UNSET
        elif isinstance(self.job_postings_v2, SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0):
            job_postings_v2 = self.job_postings_v2.to_dict()
        else:
            job_postings_v2 = self.job_postings_v2

        job_posting_stats: Union[None, Unset, dict[str, Any]]
        if isinstance(self.job_posting_stats, Unset):
            job_posting_stats = UNSET
        elif isinstance(self.job_posting_stats, SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0):
            job_posting_stats = self.job_posting_stats.to_dict()
        else:
            job_posting_stats = self.job_posting_stats

        office_locations_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.office_locations_v2, Unset):
            office_locations_v2 = UNSET
        elif isinstance(self.office_locations_v2, SyncCombinedSearchBodyCompanyParamsOfficeLocationsV2Type0):
            office_locations_v2 = self.office_locations_v2.to_dict()
        else:
            office_locations_v2 = self.office_locations_v2

        tlds: Union[None, Unset, dict[str, Any]]
        if isinstance(self.tlds, Unset):
            tlds = UNSET
        elif isinstance(self.tlds, SyncCombinedSearchBodyCompanyParamsTldsType0):
            tlds = self.tlds.to_dict()
        else:
            tlds = self.tlds

        num_words_in_name: Union[None, Unset, dict[str, Any]]
        if isinstance(self.num_words_in_name, Unset):
            num_words_in_name = UNSET
        elif isinstance(self.num_words_in_name, SyncCombinedSearchBodyCompanyParamsNumWordsInNameType0):
            num_words_in_name = self.num_words_in_name.to_dict()
        else:
            num_words_in_name = self.num_words_in_name

        status: Union[None, Unset, dict[str, Any]]
        if isinstance(self.status, Unset):
            status = UNSET
        elif isinstance(self.status, SyncCombinedSearchBodyCompanyParamsStatusType0):
            status = self.status.to_dict()
        else:
            status = self.status

        technologies: Union[None, Unset, dict[str, Any]]
        if isinstance(self.technologies, Unset):
            technologies = UNSET
        elif isinstance(self.technologies, SyncCombinedSearchBodyCompanyParamsTechnologiesType0):
            technologies = self.technologies.to_dict()
        else:
            technologies = self.technologies

        investors: Union[None, Unset, dict[str, Any]]
        if isinstance(self.investors, Unset):
            investors = UNSET
        elif isinstance(self.investors, SyncCombinedSearchBodyCompanyParamsInvestorsType0):
            investors = self.investors.to_dict()
        else:
            investors = self.investors

        tags: Union[None, Unset, dict[str, Any]]
        if isinstance(self.tags, Unset):
            tags = UNSET
        elif isinstance(self.tags, SyncCombinedSearchBodyCompanyParamsTagsType0):
            tags = self.tags.to_dict()
        else:
            tags = self.tags

        crunchbase_categories: Union[None, Unset, dict[str, Any]]
        if isinstance(self.crunchbase_categories, Unset):
            crunchbase_categories = UNSET
        elif isinstance(self.crunchbase_categories, SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoriesType0):
            crunchbase_categories = self.crunchbase_categories.to_dict()
        else:
            crunchbase_categories = self.crunchbase_categories

        crunchbase_category_groups: Union[None, Unset, dict[str, Any]]
        if isinstance(self.crunchbase_category_groups, Unset):
            crunchbase_category_groups = UNSET
        elif isinstance(self.crunchbase_category_groups, SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoryGroupsType0):
            crunchbase_category_groups = self.crunchbase_category_groups.to_dict()
        else:
            crunchbase_category_groups = self.crunchbase_category_groups

        linkedin_industries: Union[None, Unset, dict[str, Any]]
        if isinstance(self.linkedin_industries, Unset):
            linkedin_industries = UNSET
        elif isinstance(self.linkedin_industries, SyncCombinedSearchBodyCompanyParamsLinkedinIndustriesType0):
            linkedin_industries = self.linkedin_industries.to_dict()
        else:
            linkedin_industries = self.linkedin_industries

        crunchbase_slugs: Union[None, Unset, list[str]]
        if isinstance(self.crunchbase_slugs, Unset):
            crunchbase_slugs = UNSET
        elif isinstance(self.crunchbase_slugs, list):
            crunchbase_slugs = self.crunchbase_slugs


        else:
            crunchbase_slugs = self.crunchbase_slugs


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if exact_company_v2 is not UNSET:
            field_dict["exactCompanyV2"] = exact_company_v2
        if domains is not UNSET:
            field_dict["domains"] = domains
        if headquarters_country_code is not UNSET:
            field_dict["headquartersCountryCode"] = headquarters_country_code
        if headquarters_state_name is not UNSET:
            field_dict["headquartersStateName"] = headquarters_state_name
        if employee_count_v2 is not UNSET:
            field_dict["employeeCountV2"] = employee_count_v2
        if keywords is not UNSET:
            field_dict["keywords"] = keywords
        if industries_v2 is not UNSET:
            field_dict["industriesV2"] = industries_v2
        if stage is not UNSET:
            field_dict["stage"] = stage
        if total_funding_usd is not UNSET:
            field_dict["totalFundingUSD"] = total_funding_usd
        if last_funding_usd is not UNSET:
            field_dict["lastFundingUSD"] = last_funding_usd
        if last_funded_on is not UNSET:
            field_dict["lastFundedOn"] = last_funded_on
        if founded_on is not UNSET:
            field_dict["foundedOn"] = founded_on
        if name_like is not UNSET:
            field_dict["nameLike"] = name_like
        if exact_company is not UNSET:
            field_dict["exactCompany"] = exact_company
        if accelerators_v2 is not UNSET:
            field_dict["acceleratorsV2"] = accelerators_v2
        if employee_trends is not UNSET:
            field_dict["employeeTrends"] = employee_trends
        if headquarters_location is not UNSET:
            field_dict["headquartersLocation"] = headquarters_location
        if linkedin_slugs is not UNSET:
            field_dict["linkedinSlugs"] = linkedin_slugs
        if special_flags is not UNSET:
            field_dict["specialFlags"] = special_flags
        if employees is not UNSET:
            field_dict["employees"] = employees
        if revenue_usd is not UNSET:
            field_dict["revenueUSD"] = revenue_usd
        if naics_codes is not UNSET:
            field_dict["naicsCodes"] = naics_codes
        if fortune_rankings is not UNSET:
            field_dict["fortuneRankings"] = fortune_rankings
        if job_postings_v2 is not UNSET:
            field_dict["jobPostingsV2"] = job_postings_v2
        if job_posting_stats is not UNSET:
            field_dict["jobPostingStats"] = job_posting_stats
        if office_locations_v2 is not UNSET:
            field_dict["officeLocationsV2"] = office_locations_v2
        if tlds is not UNSET:
            field_dict["tlds"] = tlds
        if num_words_in_name is not UNSET:
            field_dict["numWordsInName"] = num_words_in_name
        if status is not UNSET:
            field_dict["status"] = status
        if technologies is not UNSET:
            field_dict["technologies"] = technologies
        if investors is not UNSET:
            field_dict["investors"] = investors
        if tags is not UNSET:
            field_dict["tags"] = tags
        if crunchbase_categories is not UNSET:
            field_dict["crunchbaseCategories"] = crunchbase_categories
        if crunchbase_category_groups is not UNSET:
            field_dict["crunchbaseCategoryGroups"] = crunchbase_category_groups
        if linkedin_industries is not UNSET:
            field_dict["linkedinIndustries"] = linkedin_industries
        if crunchbase_slugs is not UNSET:
            field_dict["crunchbaseSlugs"] = crunchbase_slugs

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sync_combined_search_body_company_params_last_funding_usd_type_0 import SyncCombinedSearchBodyCompanyParamsLastFundingUSDType0
        from ..models.sync_combined_search_body_company_params_headquarters_country_code_type_0 import SyncCombinedSearchBodyCompanyParamsHeadquartersCountryCodeType0
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0
        from ..models.sync_combined_search_body_company_params_num_words_in_name_type_0 import SyncCombinedSearchBodyCompanyParamsNumWordsInNameType0
        from ..models.sync_combined_search_body_company_params_naics_codes_type_0 import SyncCombinedSearchBodyCompanyParamsNaicsCodesType0
        from ..models.sync_combined_search_body_company_params_tlds_type_0 import SyncCombinedSearchBodyCompanyParamsTldsType0
        from ..models.sync_combined_search_body_company_params_founded_on_type_1 import SyncCombinedSearchBodyCompanyParamsFoundedOnType1
        from ..models.sync_combined_search_body_company_params_name_like_type_0 import SyncCombinedSearchBodyCompanyParamsNameLikeType0
        from ..models.sync_combined_search_body_company_params_revenue_usd_type_0 import SyncCombinedSearchBodyCompanyParamsRevenueUSDType0
        from ..models.sync_combined_search_body_company_params_status_type_0 import SyncCombinedSearchBodyCompanyParamsStatusType0
        from ..models.sync_combined_search_body_company_params_fortune_rankings_type_0 import SyncCombinedSearchBodyCompanyParamsFortuneRankingsType0
        from ..models.sync_combined_search_body_company_params_exact_company_v2_type_0 import SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0
        from ..models.sync_combined_search_body_company_params_industries_v2_type_0 import SyncCombinedSearchBodyCompanyParamsIndustriesV2Type0
        from ..models.sync_combined_search_body_company_params_keywords_type_0 import SyncCombinedSearchBodyCompanyParamsKeywordsType0
        from ..models.sync_combined_search_body_company_params_exact_company_type_0 import SyncCombinedSearchBodyCompanyParamsExactCompanyType0
        from ..models.sync_combined_search_body_company_params_special_flags_type_0 import SyncCombinedSearchBodyCompanyParamsSpecialFlagsType0
        from ..models.sync_combined_search_body_company_params_accelerators_v2_type_0 import SyncCombinedSearchBodyCompanyParamsAcceleratorsV2Type0
        from ..models.sync_combined_search_body_company_params_tags_type_0 import SyncCombinedSearchBodyCompanyParamsTagsType0
        from ..models.sync_combined_search_body_company_params_investors_type_0 import SyncCombinedSearchBodyCompanyParamsInvestorsType0
        from ..models.sync_combined_search_body_company_params_founded_on_type_0 import SyncCombinedSearchBodyCompanyParamsFoundedOnType0
        from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0
        from ..models.sync_combined_search_body_company_params_total_funding_usd_type_0 import SyncCombinedSearchBodyCompanyParamsTotalFundingUSDType0
        from ..models.sync_combined_search_body_company_params_headquarters_state_name_type_0 import SyncCombinedSearchBodyCompanyParamsHeadquartersStateNameType0
        from ..models.sync_combined_search_body_company_params_crunchbase_categories_type_0 import SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoriesType0
        from ..models.sync_combined_search_body_company_params_employee_count_v2_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0
        from ..models.sync_combined_search_body_company_params_employees_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeesType0
        from ..models.sync_combined_search_body_company_params_crunchbase_category_groups_type_0 import SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoryGroupsType0
        from ..models.sync_combined_search_body_company_params_job_posting_stats_type_0 import SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0
        from ..models.sync_combined_search_body_company_params_last_funded_on_type_0 import SyncCombinedSearchBodyCompanyParamsLastFundedOnType0
        from ..models.sync_combined_search_body_company_params_technologies_type_0 import SyncCombinedSearchBodyCompanyParamsTechnologiesType0
        from ..models.sync_combined_search_body_company_params_stage_type_0 import SyncCombinedSearchBodyCompanyParamsStageType0
        from ..models.sync_combined_search_body_company_params_office_locations_v2_type_0 import SyncCombinedSearchBodyCompanyParamsOfficeLocationsV2Type0
        from ..models.sync_combined_search_body_company_params_headquarters_location_type_0 import SyncCombinedSearchBodyCompanyParamsHeadquartersLocationType0
        from ..models.sync_combined_search_body_company_params_linkedin_industries_type_0 import SyncCombinedSearchBodyCompanyParamsLinkedinIndustriesType0
        from ..models.sync_combined_search_body_company_params_last_funded_on_type_1 import SyncCombinedSearchBodyCompanyParamsLastFundedOnType1
        d = dict(src_dict)
        def _parse_exact_company_v2(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                exact_company_v2_type_0 = SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0.from_dict(data)



                return exact_company_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0', None, Unset], data)

        exact_company_v2 = _parse_exact_company_v2(d.pop("exactCompanyV2", UNSET))


        def _parse_domains(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                domains_type_0 = cast(list[str], data)

                return domains_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        domains = _parse_domains(d.pop("domains", UNSET))


        def _parse_headquarters_country_code(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsHeadquartersCountryCodeType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                headquarters_country_code_type_0 = SyncCombinedSearchBodyCompanyParamsHeadquartersCountryCodeType0.from_dict(data)



                return headquarters_country_code_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsHeadquartersCountryCodeType0', None, Unset], data)

        headquarters_country_code = _parse_headquarters_country_code(d.pop("headquartersCountryCode", UNSET))


        def _parse_headquarters_state_name(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsHeadquartersStateNameType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                headquarters_state_name_type_0 = SyncCombinedSearchBodyCompanyParamsHeadquartersStateNameType0.from_dict(data)



                return headquarters_state_name_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsHeadquartersStateNameType0', None, Unset], data)

        headquarters_state_name = _parse_headquarters_state_name(d.pop("headquartersStateName", UNSET))


        def _parse_employee_count_v2(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                employee_count_v2_type_0 = SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0.from_dict(data)



                return employee_count_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0', None, Unset], data)

        employee_count_v2 = _parse_employee_count_v2(d.pop("employeeCountV2", UNSET))


        def _parse_keywords(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsKeywordsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                keywords_type_0 = SyncCombinedSearchBodyCompanyParamsKeywordsType0.from_dict(data)



                return keywords_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsKeywordsType0', None, Unset], data)

        keywords = _parse_keywords(d.pop("keywords", UNSET))


        def _parse_industries_v2(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsIndustriesV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                industries_v2_type_0 = SyncCombinedSearchBodyCompanyParamsIndustriesV2Type0.from_dict(data)



                return industries_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsIndustriesV2Type0', None, Unset], data)

        industries_v2 = _parse_industries_v2(d.pop("industriesV2", UNSET))


        def _parse_stage(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsStageType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                stage_type_0 = SyncCombinedSearchBodyCompanyParamsStageType0.from_dict(data)



                return stage_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsStageType0', None, Unset], data)

        stage = _parse_stage(d.pop("stage", UNSET))


        def _parse_total_funding_usd(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsTotalFundingUSDType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                total_funding_usd_type_0 = SyncCombinedSearchBodyCompanyParamsTotalFundingUSDType0.from_dict(data)



                return total_funding_usd_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsTotalFundingUSDType0', None, Unset], data)

        total_funding_usd = _parse_total_funding_usd(d.pop("totalFundingUSD", UNSET))


        def _parse_last_funding_usd(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsLastFundingUSDType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                last_funding_usd_type_0 = SyncCombinedSearchBodyCompanyParamsLastFundingUSDType0.from_dict(data)



                return last_funding_usd_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsLastFundingUSDType0', None, Unset], data)

        last_funding_usd = _parse_last_funding_usd(d.pop("lastFundingUSD", UNSET))


        def _parse_last_funded_on(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsLastFundedOnType0', 'SyncCombinedSearchBodyCompanyParamsLastFundedOnType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                last_funded_on_type_0 = SyncCombinedSearchBodyCompanyParamsLastFundedOnType0.from_dict(data)



                return last_funded_on_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                last_funded_on_type_1 = SyncCombinedSearchBodyCompanyParamsLastFundedOnType1.from_dict(data)



                return last_funded_on_type_1
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsLastFundedOnType0', 'SyncCombinedSearchBodyCompanyParamsLastFundedOnType1', None, Unset], data)

        last_funded_on = _parse_last_funded_on(d.pop("lastFundedOn", UNSET))


        def _parse_founded_on(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsFoundedOnType0', 'SyncCombinedSearchBodyCompanyParamsFoundedOnType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                founded_on_type_0 = SyncCombinedSearchBodyCompanyParamsFoundedOnType0.from_dict(data)



                return founded_on_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                founded_on_type_1 = SyncCombinedSearchBodyCompanyParamsFoundedOnType1.from_dict(data)



                return founded_on_type_1
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsFoundedOnType0', 'SyncCombinedSearchBodyCompanyParamsFoundedOnType1', None, Unset], data)

        founded_on = _parse_founded_on(d.pop("foundedOn", UNSET))


        def _parse_name_like(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsNameLikeType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                name_like_type_0 = SyncCombinedSearchBodyCompanyParamsNameLikeType0.from_dict(data)



                return name_like_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsNameLikeType0', None, Unset], data)

        name_like = _parse_name_like(d.pop("nameLike", UNSET))


        def _parse_exact_company(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsExactCompanyType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                exact_company_type_0 = SyncCombinedSearchBodyCompanyParamsExactCompanyType0.from_dict(data)



                return exact_company_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsExactCompanyType0', None, Unset], data)

        exact_company = _parse_exact_company(d.pop("exactCompany", UNSET))


        def _parse_accelerators_v2(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsAcceleratorsV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                accelerators_v2_type_0 = SyncCombinedSearchBodyCompanyParamsAcceleratorsV2Type0.from_dict(data)



                return accelerators_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsAcceleratorsV2Type0', None, Unset], data)

        accelerators_v2 = _parse_accelerators_v2(d.pop("acceleratorsV2", UNSET))


        def _parse_employee_trends(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                employee_trends_type_0 = SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0.from_dict(data)



                return employee_trends_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0', None, Unset], data)

        employee_trends = _parse_employee_trends(d.pop("employeeTrends", UNSET))


        def _parse_headquarters_location(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsHeadquartersLocationType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                headquarters_location_type_0 = SyncCombinedSearchBodyCompanyParamsHeadquartersLocationType0.from_dict(data)



                return headquarters_location_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsHeadquartersLocationType0', None, Unset], data)

        headquarters_location = _parse_headquarters_location(d.pop("headquartersLocation", UNSET))


        def _parse_linkedin_slugs(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                linkedin_slugs_type_0 = cast(list[str], data)

                return linkedin_slugs_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        linkedin_slugs = _parse_linkedin_slugs(d.pop("linkedinSlugs", UNSET))


        def _parse_special_flags(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsSpecialFlagsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                special_flags_type_0 = SyncCombinedSearchBodyCompanyParamsSpecialFlagsType0.from_dict(data)



                return special_flags_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsSpecialFlagsType0', None, Unset], data)

        special_flags = _parse_special_flags(d.pop("specialFlags", UNSET))


        def _parse_employees(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsEmployeesType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                employees_type_0 = SyncCombinedSearchBodyCompanyParamsEmployeesType0.from_dict(data)



                return employees_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsEmployeesType0', None, Unset], data)

        employees = _parse_employees(d.pop("employees", UNSET))


        def _parse_revenue_usd(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsRevenueUSDType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                revenue_usd_type_0 = SyncCombinedSearchBodyCompanyParamsRevenueUSDType0.from_dict(data)



                return revenue_usd_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsRevenueUSDType0', None, Unset], data)

        revenue_usd = _parse_revenue_usd(d.pop("revenueUSD", UNSET))


        def _parse_naics_codes(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsNaicsCodesType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                naics_codes_type_0 = SyncCombinedSearchBodyCompanyParamsNaicsCodesType0.from_dict(data)



                return naics_codes_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsNaicsCodesType0', None, Unset], data)

        naics_codes = _parse_naics_codes(d.pop("naicsCodes", UNSET))


        def _parse_fortune_rankings(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsFortuneRankingsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                fortune_rankings_type_0 = SyncCombinedSearchBodyCompanyParamsFortuneRankingsType0.from_dict(data)



                return fortune_rankings_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsFortuneRankingsType0', None, Unset], data)

        fortune_rankings = _parse_fortune_rankings(d.pop("fortuneRankings", UNSET))


        def _parse_job_postings_v2(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                job_postings_v2_type_0 = SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0.from_dict(data)



                return job_postings_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0', None, Unset], data)

        job_postings_v2 = _parse_job_postings_v2(d.pop("jobPostingsV2", UNSET))


        def _parse_job_posting_stats(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                job_posting_stats_type_0 = SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0.from_dict(data)



                return job_posting_stats_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0', None, Unset], data)

        job_posting_stats = _parse_job_posting_stats(d.pop("jobPostingStats", UNSET))


        def _parse_office_locations_v2(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsOfficeLocationsV2Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                office_locations_v2_type_0 = SyncCombinedSearchBodyCompanyParamsOfficeLocationsV2Type0.from_dict(data)



                return office_locations_v2_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsOfficeLocationsV2Type0', None, Unset], data)

        office_locations_v2 = _parse_office_locations_v2(d.pop("officeLocationsV2", UNSET))


        def _parse_tlds(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsTldsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                tlds_type_0 = SyncCombinedSearchBodyCompanyParamsTldsType0.from_dict(data)



                return tlds_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsTldsType0', None, Unset], data)

        tlds = _parse_tlds(d.pop("tlds", UNSET))


        def _parse_num_words_in_name(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsNumWordsInNameType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                num_words_in_name_type_0 = SyncCombinedSearchBodyCompanyParamsNumWordsInNameType0.from_dict(data)



                return num_words_in_name_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsNumWordsInNameType0', None, Unset], data)

        num_words_in_name = _parse_num_words_in_name(d.pop("numWordsInName", UNSET))


        def _parse_status(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsStatusType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                status_type_0 = SyncCombinedSearchBodyCompanyParamsStatusType0.from_dict(data)



                return status_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsStatusType0', None, Unset], data)

        status = _parse_status(d.pop("status", UNSET))


        def _parse_technologies(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsTechnologiesType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                technologies_type_0 = SyncCombinedSearchBodyCompanyParamsTechnologiesType0.from_dict(data)



                return technologies_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsTechnologiesType0', None, Unset], data)

        technologies = _parse_technologies(d.pop("technologies", UNSET))


        def _parse_investors(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsInvestorsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                investors_type_0 = SyncCombinedSearchBodyCompanyParamsInvestorsType0.from_dict(data)



                return investors_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsInvestorsType0', None, Unset], data)

        investors = _parse_investors(d.pop("investors", UNSET))


        def _parse_tags(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsTagsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                tags_type_0 = SyncCombinedSearchBodyCompanyParamsTagsType0.from_dict(data)



                return tags_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsTagsType0', None, Unset], data)

        tags = _parse_tags(d.pop("tags", UNSET))


        def _parse_crunchbase_categories(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoriesType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                crunchbase_categories_type_0 = SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoriesType0.from_dict(data)



                return crunchbase_categories_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoriesType0', None, Unset], data)

        crunchbase_categories = _parse_crunchbase_categories(d.pop("crunchbaseCategories", UNSET))


        def _parse_crunchbase_category_groups(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoryGroupsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                crunchbase_category_groups_type_0 = SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoryGroupsType0.from_dict(data)



                return crunchbase_category_groups_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsCrunchbaseCategoryGroupsType0', None, Unset], data)

        crunchbase_category_groups = _parse_crunchbase_category_groups(d.pop("crunchbaseCategoryGroups", UNSET))


        def _parse_linkedin_industries(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsLinkedinIndustriesType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                linkedin_industries_type_0 = SyncCombinedSearchBodyCompanyParamsLinkedinIndustriesType0.from_dict(data)



                return linkedin_industries_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsLinkedinIndustriesType0', None, Unset], data)

        linkedin_industries = _parse_linkedin_industries(d.pop("linkedinIndustries", UNSET))


        def _parse_crunchbase_slugs(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                crunchbase_slugs_type_0 = cast(list[str], data)

                return crunchbase_slugs_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        crunchbase_slugs = _parse_crunchbase_slugs(d.pop("crunchbaseSlugs", UNSET))


        sync_combined_search_body_company_params = cls(
            exact_company_v2=exact_company_v2,
            domains=domains,
            headquarters_country_code=headquarters_country_code,
            headquarters_state_name=headquarters_state_name,
            employee_count_v2=employee_count_v2,
            keywords=keywords,
            industries_v2=industries_v2,
            stage=stage,
            total_funding_usd=total_funding_usd,
            last_funding_usd=last_funding_usd,
            last_funded_on=last_funded_on,
            founded_on=founded_on,
            name_like=name_like,
            exact_company=exact_company,
            accelerators_v2=accelerators_v2,
            employee_trends=employee_trends,
            headquarters_location=headquarters_location,
            linkedin_slugs=linkedin_slugs,
            special_flags=special_flags,
            employees=employees,
            revenue_usd=revenue_usd,
            naics_codes=naics_codes,
            fortune_rankings=fortune_rankings,
            job_postings_v2=job_postings_v2,
            job_posting_stats=job_posting_stats,
            office_locations_v2=office_locations_v2,
            tlds=tlds,
            num_words_in_name=num_words_in_name,
            status=status,
            technologies=technologies,
            investors=investors,
            tags=tags,
            crunchbase_categories=crunchbase_categories,
            crunchbase_category_groups=crunchbase_category_groups,
            linkedin_industries=linkedin_industries,
            crunchbase_slugs=crunchbase_slugs,
        )


        sync_combined_search_body_company_params.additional_properties = d
        return sync_combined_search_body_company_params

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import IntEnum

class TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0LowerBoundExclusiveType2(IntEnum):
    VALUE_10 = 10

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType0Rule(str, Enum):
    TOTAL = "total"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.start_batch_contact_enrichment_body_person_details_item_linkedin_url import StartBatchContactEnrichmentBodyPersonDetailsItemLinkedinUrl





T = TypeVar("T", bound="StartBatchContactEnrichmentBodyPersonDetailsItem")



@_attrs_define
class StartBatchContactEnrichmentBodyPersonDetailsItem:
    """ 
        Attributes:
            linkedin_url (StartBatchContactEnrichmentBodyPersonDetailsItemLinkedinUrl):
     """

    linkedin_url: 'StartBatchContactEnrichmentBodyPersonDetailsItemLinkedinUrl'
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.start_batch_contact_enrichment_body_person_details_item_linkedin_url import StartBatchContactEnrichmentBodyPersonDetailsItemLinkedinUrl
        linkedin_url = self.linkedin_url.to_dict()


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "linkedinUrl": linkedin_url,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.start_batch_contact_enrichment_body_person_details_item_linkedin_url import StartBatchContactEnrichmentBodyPersonDetailsItemLinkedinUrl
        d = dict(src_dict)
        linkedin_url = StartBatchContactEnrichmentBodyPersonDetailsItemLinkedinUrl.from_dict(d.pop("linkedinUrl"))




        start_batch_contact_enrichment_body_person_details_item = cls(
            linkedin_url=linkedin_url,
        )


        start_batch_contact_enrichment_body_person_details_item.additional_properties = d
        return start_batch_contact_enrichment_body_person_details_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.sync_combined_search_response_200_output_profiles_item import SyncCombinedSearchResponse200OutputProfilesItem
  from ..models.sync_combined_search_response_200_output_companies_item import SyncCombinedSearchResponse200OutputCompaniesItem





T = TypeVar("T", bound="SyncCombinedSearchResponse200Output")



@_attrs_define
class SyncCombinedSearchResponse200Output:
    """ 
        Attributes:
            companies (list['SyncCombinedSearchResponse200OutputCompaniesItem']):
            profiles (list['SyncCombinedSearchResponse200OutputProfilesItem']):
     """

    companies: list['SyncCombinedSearchResponse200OutputCompaniesItem']
    profiles: list['SyncCombinedSearchResponse200OutputProfilesItem']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.sync_combined_search_response_200_output_profiles_item import SyncCombinedSearchResponse200OutputProfilesItem
        from ..models.sync_combined_search_response_200_output_companies_item import SyncCombinedSearchResponse200OutputCompaniesItem
        companies = []
        for companies_item_data in self.companies:
            companies_item = companies_item_data.to_dict()
            companies.append(companies_item)



        profiles = []
        for profiles_item_data in self.profiles:
            profiles_item = profiles_item_data.to_dict()
            profiles.append(profiles_item)




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "companies": companies,
            "profiles": profiles,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sync_combined_search_response_200_output_profiles_item import SyncCombinedSearchResponse200OutputProfilesItem
        from ..models.sync_combined_search_response_200_output_companies_item import SyncCombinedSearchResponse200OutputCompaniesItem
        d = dict(src_dict)
        companies = []
        _companies = d.pop("companies")
        for companies_item_data in (_companies):
            companies_item = SyncCombinedSearchResponse200OutputCompaniesItem.from_dict(companies_item_data)



            companies.append(companies_item)


        profiles = []
        _profiles = d.pop("profiles")
        for profiles_item_data in (_profiles):
            profiles_item = SyncCombinedSearchResponse200OutputProfilesItem.from_dict(profiles_item_data)



            profiles.append(profiles_item)


        sync_combined_search_response_200_output = cls(
            companies=companies,
            profiles=profiles,
        )


        sync_combined_search_response_200_output.additional_properties = d
        return sync_combined_search_response_200_output

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.create_saved_search_body import CreateSavedSearchBody
from ...models.create_saved_search_response_200 import CreateSavedSearchResponse200
from ...models.create_saved_search_response_400 import CreateSavedSearchResponse400
from ...models.create_saved_search_response_401 import CreateSavedSearchResponse401
from ...models.create_saved_search_response_402 import CreateSavedSearchResponse402
from ...models.create_saved_search_response_403 import CreateSavedSearchResponse403
from ...models.create_saved_search_response_404 import CreateSavedSearchResponse404
from ...models.create_saved_search_response_429 import CreateSavedSearchResponse429
from ...models.create_saved_search_response_500 import CreateSavedSearchResponse500
from typing import cast



def _get_kwargs(
    *,
    body: CreateSavedSearchBody,

) -> dict[str, Any]:
    headers: dict[str, Any] = {}


    

    

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/v1/saved-search/create",
    }

    _kwargs["json"] = body.to_dict()


    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs



def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Union[CreateSavedSearchResponse200, CreateSavedSearchResponse400, CreateSavedSearchResponse401, CreateSavedSearchResponse402, CreateSavedSearchResponse403, CreateSavedSearchResponse404, CreateSavedSearchResponse429, CreateSavedSearchResponse500]]:
    if response.status_code == 200:
        response_200 = CreateSavedSearchResponse200.from_dict(response.json())



        return response_200

    if response.status_code == 400:
        response_400 = CreateSavedSearchResponse400.from_dict(response.json())



        return response_400

    if response.status_code == 401:
        response_401 = CreateSavedSearchResponse401.from_dict(response.json())



        return response_401

    if response.status_code == 402:
        response_402 = CreateSavedSearchResponse402.from_dict(response.json())



        return response_402

    if response.status_code == 403:
        response_403 = CreateSavedSearchResponse403.from_dict(response.json())



        return response_403

    if response.status_code == 404:
        response_404 = CreateSavedSearchResponse404.from_dict(response.json())



        return response_404

    if response.status_code == 429:
        response_429 = CreateSavedSearchResponse429.from_dict(response.json())



        return response_429

    if response.status_code == 500:
        response_500 = CreateSavedSearchResponse500.from_dict(response.json())



        return response_500

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Union[CreateSavedSearchResponse200, CreateSavedSearchResponse400, CreateSavedSearchResponse401, CreateSavedSearchResponse402, CreateSavedSearchResponse403, CreateSavedSearchResponse404, CreateSavedSearchResponse429, CreateSavedSearchResponse500]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreateSavedSearchBody,

) -> Response[Union[CreateSavedSearchResponse200, CreateSavedSearchResponse400, CreateSavedSearchResponse401, CreateSavedSearchResponse402, CreateSavedSearchResponse403, CreateSavedSearchResponse404, CreateSavedSearchResponse429, CreateSavedSearchResponse500]]:
    r""" Create saved search

     Create a new saved search. Given search params, it automatically re-runs it periodically and tells
    you which new people and/or companies fit your parameters over time (and also who drops out or
    returns). You are charged for each new prospect or company we find, depending on your desired type.
    You can also manually run the saved search if you don't want to wait for the next auto-run.

    <span>⚡ <strong>Rate limit:</strong> 10 requests per 1 minute</span>

    <span>💰 <strong>Cost:</strong> 2 credits per prospect/company found in search&nbsp;<span
    title=\"Pricing shown is default pricing. Actual pricing may vary.\">ⓘ</span></span>

    Args:
        body (CreateSavedSearchBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CreateSavedSearchResponse200, CreateSavedSearchResponse400, CreateSavedSearchResponse401, CreateSavedSearchResponse402, CreateSavedSearchResponse403, CreateSavedSearchResponse404, CreateSavedSearchResponse429, CreateSavedSearchResponse500]]
     """


    kwargs = _get_kwargs(
        body=body,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreateSavedSearchBody,

) -> Optional[Union[CreateSavedSearchResponse200, CreateSavedSearchResponse400, CreateSavedSearchResponse401, CreateSavedSearchResponse402, CreateSavedSearchResponse403, CreateSavedSearchResponse404, CreateSavedSearchResponse429, CreateSavedSearchResponse500]]:
    r""" Create saved search

     Create a new saved search. Given search params, it automatically re-runs it periodically and tells
    you which new people and/or companies fit your parameters over time (and also who drops out or
    returns). You are charged for each new prospect or company we find, depending on your desired type.
    You can also manually run the saved search if you don't want to wait for the next auto-run.

    <span>⚡ <strong>Rate limit:</strong> 10 requests per 1 minute</span>

    <span>💰 <strong>Cost:</strong> 2 credits per prospect/company found in search&nbsp;<span
    title=\"Pricing shown is default pricing. Actual pricing may vary.\">ⓘ</span></span>

    Args:
        body (CreateSavedSearchBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CreateSavedSearchResponse200, CreateSavedSearchResponse400, CreateSavedSearchResponse401, CreateSavedSearchResponse402, CreateSavedSearchResponse403, CreateSavedSearchResponse404, CreateSavedSearchResponse429, CreateSavedSearchResponse500]
     """


    return sync_detailed(
        client=client,
body=body,

    ).parsed

async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreateSavedSearchBody,

) -> Response[Union[CreateSavedSearchResponse200, CreateSavedSearchResponse400, CreateSavedSearchResponse401, CreateSavedSearchResponse402, CreateSavedSearchResponse403, CreateSavedSearchResponse404, CreateSavedSearchResponse429, CreateSavedSearchResponse500]]:
    r""" Create saved search

     Create a new saved search. Given search params, it automatically re-runs it periodically and tells
    you which new people and/or companies fit your parameters over time (and also who drops out or
    returns). You are charged for each new prospect or company we find, depending on your desired type.
    You can also manually run the saved search if you don't want to wait for the next auto-run.

    <span>⚡ <strong>Rate limit:</strong> 10 requests per 1 minute</span>

    <span>💰 <strong>Cost:</strong> 2 credits per prospect/company found in search&nbsp;<span
    title=\"Pricing shown is default pricing. Actual pricing may vary.\">ⓘ</span></span>

    Args:
        body (CreateSavedSearchBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CreateSavedSearchResponse200, CreateSavedSearchResponse400, CreateSavedSearchResponse401, CreateSavedSearchResponse402, CreateSavedSearchResponse403, CreateSavedSearchResponse404, CreateSavedSearchResponse429, CreateSavedSearchResponse500]]
     """


    kwargs = _get_kwargs(
        body=body,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreateSavedSearchBody,

) -> Optional[Union[CreateSavedSearchResponse200, CreateSavedSearchResponse400, CreateSavedSearchResponse401, CreateSavedSearchResponse402, CreateSavedSearchResponse403, CreateSavedSearchResponse404, CreateSavedSearchResponse429, CreateSavedSearchResponse500]]:
    r""" Create saved search

     Create a new saved search. Given search params, it automatically re-runs it periodically and tells
    you which new people and/or companies fit your parameters over time (and also who drops out or
    returns). You are charged for each new prospect or company we find, depending on your desired type.
    You can also manually run the saved search if you don't want to wait for the next auto-run.

    <span>⚡ <strong>Rate limit:</strong> 10 requests per 1 minute</span>

    <span>💰 <strong>Cost:</strong> 2 credits per prospect/company found in search&nbsp;<span
    title=\"Pricing shown is default pricing. Actual pricing may vary.\">ⓘ</span></span>

    Args:
        body (CreateSavedSearchBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CreateSavedSearchResponse200, CreateSavedSearchResponse400, CreateSavedSearchResponse401, CreateSavedSearchResponse402, CreateSavedSearchResponse403, CreateSavedSearchResponse404, CreateSavedSearchResponse429, CreateSavedSearchResponse500]
     """


    return (await asyncio_detailed(
        client=client,
body=body,

    )).parsed



from enum import Enum

class DomainLookupPollingResponse200OutputStatus(str, Enum):
    DONE = "DONE"
    FAILED = "FAILED"
    NOT_STARTED = "NOT_STARTED"
    STARTED = "STARTED"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.remove_prospect_from_exclusion_list_response_200_charge_info_type_0_method import RemoveProspectFromExclusionListResponse200ChargeInfoType0Method






T = TypeVar("T", bound="RemoveProspectFromExclusionListResponse200ChargeInfoType0")



@_attrs_define
class RemoveProspectFromExclusionListResponse200ChargeInfoType0:
    """ Credits were charged immediately for this operation

        Attributes:
            method (RemoveProspectFromExclusionListResponse200ChargeInfoType0Method):
            credits_charged (float):
     """

    method: RemoveProspectFromExclusionListResponse200ChargeInfoType0Method
    credits_charged: float
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        method = self.method.value

        credits_charged = self.credits_charged


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "method": method,
            "creditsCharged": credits_charged,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        method = RemoveProspectFromExclusionListResponse200ChargeInfoType0Method(d.pop("method"))




        credits_charged = d.pop("creditsCharged")

        remove_prospect_from_exclusion_list_response_200_charge_info_type_0 = cls(
            method=method,
            credits_charged=credits_charged,
        )


        remove_prospect_from_exclusion_list_response_200_charge_info_type_0.additional_properties = d
        return remove_prospect_from_exclusion_list_response_200_charge_info_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class PeopleSearchBodySearchParamsJobTitleV2Type0AllOfType0ItemType1Type(str, Enum):
    STATIC_GROUPS = "static-groups"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.people_search_body_search_params_location_type_0_union_all_type_0_item_type_0_strategy import PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0Strategy
from typing import cast
from typing import cast, Union

if TYPE_CHECKING:
  from ..models.people_search_body_search_params_location_type_0_union_all_type_0_item_type_0_radius_type_0 import PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType0
  from ..models.people_search_body_search_params_location_type_0_union_all_type_0_item_type_0_radius_type_1 import PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType1
  from ..models.people_search_body_search_params_location_type_0_union_all_type_0_item_type_0_center import PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0Center





T = TypeVar("T", bound="PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0")



@_attrs_define
class PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0:
    """ 
        Attributes:
            strategy (PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0Strategy):
            center (PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0Center):
            radius (Union['PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType0',
                'PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType1']):
     """

    strategy: PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0Strategy
    center: 'PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0Center'
    radius: Union['PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType0', 'PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType1']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.people_search_body_search_params_location_type_0_union_all_type_0_item_type_0_radius_type_0 import PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType0
        from ..models.people_search_body_search_params_location_type_0_union_all_type_0_item_type_0_radius_type_1 import PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType1
        from ..models.people_search_body_search_params_location_type_0_union_all_type_0_item_type_0_center import PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0Center
        strategy = self.strategy.value

        center = self.center.to_dict()

        radius: dict[str, Any]
        if isinstance(self.radius, PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType0):
            radius = self.radius.to_dict()
        else:
            radius = self.radius.to_dict()



        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "strategy": strategy,
            "center": center,
            "radius": radius,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.people_search_body_search_params_location_type_0_union_all_type_0_item_type_0_radius_type_0 import PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType0
        from ..models.people_search_body_search_params_location_type_0_union_all_type_0_item_type_0_radius_type_1 import PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType1
        from ..models.people_search_body_search_params_location_type_0_union_all_type_0_item_type_0_center import PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0Center
        d = dict(src_dict)
        strategy = PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0Strategy(d.pop("strategy"))




        center = PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0Center.from_dict(d.pop("center"))




        def _parse_radius(data: object) -> Union['PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType0', 'PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType1']:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                radius_type_0 = PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType0.from_dict(data)



                return radius_type_0
            except: # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            radius_type_1 = PeopleSearchBodySearchParamsLocationType0UnionAllType0ItemType0RadiusType1.from_dict(data)



            return radius_type_1

        radius = _parse_radius(d.pop("radius"))


        people_search_body_search_params_location_type_0_union_all_type_0_item_type_0 = cls(
            strategy=strategy,
            center=center,
            radius=radius,
        )


        people_search_body_search_params_location_type_0_union_all_type_0_item_type_0.additional_properties = d
        return people_search_body_search_params_location_type_0_union_all_type_0_item_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.combined_search_body_profile_params_job_title_v2_type_0_none_of_type_0_item_type_2_groups_item import CombinedSearchBodyProfileParamsJobTitleV2Type0NoneOfType0ItemType2GroupsItem
from ..models.combined_search_body_profile_params_job_title_v2_type_0_none_of_type_0_item_type_2_type import CombinedSearchBodyProfileParamsJobTitleV2Type0NoneOfType0ItemType2Type
from ..types import UNSET, Unset
from typing import cast
from typing import Union






T = TypeVar("T", bound="CombinedSearchBodyProfileParamsJobTitleV2Type0NoneOfType0ItemType2")



@_attrs_define
class CombinedSearchBodyProfileParamsJobTitleV2Type0NoneOfType0ItemType2:
    """ 
        Attributes:
            type_ (CombinedSearchBodyProfileParamsJobTitleV2Type0NoneOfType0ItemType2Type):
            groups (list[CombinedSearchBodyProfileParamsJobTitleV2Type0NoneOfType0ItemType2GroupsItem]):
            keywords (Union[Unset, list[str]]):
     """

    type_: CombinedSearchBodyProfileParamsJobTitleV2Type0NoneOfType0ItemType2Type
    groups: list[CombinedSearchBodyProfileParamsJobTitleV2Type0NoneOfType0ItemType2GroupsItem]
    keywords: Union[Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_.value

        groups = []
        for groups_item_data in self.groups:
            groups_item = groups_item_data.value
            groups.append(groups_item)



        keywords: Union[Unset, list[str]] = UNSET
        if not isinstance(self.keywords, Unset):
            keywords = self.keywords




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "groups": groups,
        })
        if keywords is not UNSET:
            field_dict["keywords"] = keywords

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = CombinedSearchBodyProfileParamsJobTitleV2Type0NoneOfType0ItemType2Type(d.pop("type"))




        groups = []
        _groups = d.pop("groups")
        for groups_item_data in (_groups):
            groups_item = CombinedSearchBodyProfileParamsJobTitleV2Type0NoneOfType0ItemType2GroupsItem(groups_item_data)



            groups.append(groups_item)


        keywords = cast(list[str], d.pop("keywords", UNSET))


        combined_search_body_profile_params_job_title_v2_type_0_none_of_type_0_item_type_2 = cls(
            type_=type_,
            groups=groups,
            keywords=keywords,
        )


        combined_search_body_profile_params_job_title_v2_type_0_none_of_type_0_item_type_2.additional_properties = d
        return combined_search_body_profile_params_job_title_v2_type_0_none_of_type_0_item_type_2

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class KitchenSinkBulkProfileBodyProfilesItemProfileIdentifierType1Identifier(str, Enum):
    LINKEDINURL = "linkedinUrl"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="PeopleSearchBodyCurrentCompaniesType0Item")



@_attrs_define
class PeopleSearchBodyCurrentCompaniesType0Item:
    """ 
        Attributes:
            domain (Union[None, Unset, str]): Company domain, like 'google.com'. Don't include 'https://', path fragments
                like '/about', or URL query parameters. If provided, we will not strip them out. This may be useful if your
                company page is like `instagram.com/google`.
            linkedin_slug_or_url (Union[None, Unset, str]): The company's linkedin slug or URL
            name (Union[None, Unset, str]): The company's name as present in LinkedIn. This would do partial matches as
                well, eg. `Fiber AI` matches with `Fiber AI (YC S23)`. Try not to rely on this field as it will simply be doing
                a loose name match. We recommend that you use the domain or LI slug if available.
            linkedin_org_id (Union[None, Unset, str]): The company's LinkedIn Organization ID, eg. 1441 for google
     """

    domain: Union[None, Unset, str] = UNSET
    linkedin_slug_or_url: Union[None, Unset, str] = UNSET
    name: Union[None, Unset, str] = UNSET
    linkedin_org_id: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        domain: Union[None, Unset, str]
        if isinstance(self.domain, Unset):
            domain = UNSET
        else:
            domain = self.domain

        linkedin_slug_or_url: Union[None, Unset, str]
        if isinstance(self.linkedin_slug_or_url, Unset):
            linkedin_slug_or_url = UNSET
        else:
            linkedin_slug_or_url = self.linkedin_slug_or_url

        name: Union[None, Unset, str]
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        linkedin_org_id: Union[None, Unset, str]
        if isinstance(self.linkedin_org_id, Unset):
            linkedin_org_id = UNSET
        else:
            linkedin_org_id = self.linkedin_org_id


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if domain is not UNSET:
            field_dict["domain"] = domain
        if linkedin_slug_or_url is not UNSET:
            field_dict["linkedinSlugOrURL"] = linkedin_slug_or_url
        if name is not UNSET:
            field_dict["name"] = name
        if linkedin_org_id is not UNSET:
            field_dict["linkedinOrgID"] = linkedin_org_id

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_domain(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        domain = _parse_domain(d.pop("domain", UNSET))


        def _parse_linkedin_slug_or_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        linkedin_slug_or_url = _parse_linkedin_slug_or_url(d.pop("linkedinSlugOrURL", UNSET))


        def _parse_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name = _parse_name(d.pop("name", UNSET))


        def _parse_linkedin_org_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        linkedin_org_id = _parse_linkedin_org_id(d.pop("linkedinOrgID", UNSET))


        people_search_body_current_companies_type_0_item = cls(
            domain=domain,
            linkedin_slug_or_url=linkedin_slug_or_url,
            name=name,
            linkedin_org_id=linkedin_org_id,
        )


        people_search_body_current_companies_type_0_item.additional_properties = d
        return people_search_body_current_companies_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsTechnologiesType0AllOfType0ItemType1Type(str, Enum):
    CUSTOM = "custom"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="CreateSavedSearchBodySearchParamsType0CompanySearchParamsSpecialFlagsType0")



@_attrs_define
class CreateSavedSearchBodySearchParamsType0CompanySearchParamsSpecialFlagsType0:
    """ 
        Attributes:
            exclude_yc_companies (Union[None, Unset, bool]):
     """

    exclude_yc_companies: Union[None, Unset, bool] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        exclude_yc_companies: Union[None, Unset, bool]
        if isinstance(self.exclude_yc_companies, Unset):
            exclude_yc_companies = UNSET
        else:
            exclude_yc_companies = self.exclude_yc_companies


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if exclude_yc_companies is not UNSET:
            field_dict["excludeYcCompanies"] = exclude_yc_companies

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_exclude_yc_companies(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        exclude_yc_companies = _parse_exclude_yc_companies(d.pop("excludeYcCompanies", UNSET))


        create_saved_search_body_search_params_type_0_company_search_params_special_flags_type_0 = cls(
            exclude_yc_companies=exclude_yc_companies,
        )


        create_saved_search_body_search_params_type_0_company_search_params_special_flags_type_0.additional_properties = d
        return create_saved_search_body_search_params_type_0_company_search_params_special_flags_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.google_maps_search_body_strategy_type_1_union_all_item_type_1_region_type import GoogleMapsSearchBodyStrategyType1UnionAllItemType1RegionType
from typing import cast

if TYPE_CHECKING:
  from ..models.google_maps_search_body_strategy_type_1_union_all_item_type_1_northwest_corner import GoogleMapsSearchBodyStrategyType1UnionAllItemType1NorthwestCorner
  from ..models.google_maps_search_body_strategy_type_1_union_all_item_type_1_southeast_corner import GoogleMapsSearchBodyStrategyType1UnionAllItemType1SoutheastCorner





T = TypeVar("T", bound="GoogleMapsSearchBodyStrategyType1UnionAllItemType1")



@_attrs_define
class GoogleMapsSearchBodyStrategyType1UnionAllItemType1:
    """ 
        Attributes:
            region_type (GoogleMapsSearchBodyStrategyType1UnionAllItemType1RegionType): Use 'rectangle' to search for places
                in a rectangle
            northwest_corner (GoogleMapsSearchBodyStrategyType1UnionAllItemType1NorthwestCorner): The coordinates of the
                north west corner of the rectangle
            southeast_corner (GoogleMapsSearchBodyStrategyType1UnionAllItemType1SoutheastCorner): The coordinates of the
                south east corner of the rectangle
     """

    region_type: GoogleMapsSearchBodyStrategyType1UnionAllItemType1RegionType
    northwest_corner: 'GoogleMapsSearchBodyStrategyType1UnionAllItemType1NorthwestCorner'
    southeast_corner: 'GoogleMapsSearchBodyStrategyType1UnionAllItemType1SoutheastCorner'
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.google_maps_search_body_strategy_type_1_union_all_item_type_1_northwest_corner import GoogleMapsSearchBodyStrategyType1UnionAllItemType1NorthwestCorner
        from ..models.google_maps_search_body_strategy_type_1_union_all_item_type_1_southeast_corner import GoogleMapsSearchBodyStrategyType1UnionAllItemType1SoutheastCorner
        region_type = self.region_type.value

        northwest_corner = self.northwest_corner.to_dict()

        southeast_corner = self.southeast_corner.to_dict()


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "regionType": region_type,
            "northwestCorner": northwest_corner,
            "southeastCorner": southeast_corner,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.google_maps_search_body_strategy_type_1_union_all_item_type_1_northwest_corner import GoogleMapsSearchBodyStrategyType1UnionAllItemType1NorthwestCorner
        from ..models.google_maps_search_body_strategy_type_1_union_all_item_type_1_southeast_corner import GoogleMapsSearchBodyStrategyType1UnionAllItemType1SoutheastCorner
        d = dict(src_dict)
        region_type = GoogleMapsSearchBodyStrategyType1UnionAllItemType1RegionType(d.pop("regionType"))




        northwest_corner = GoogleMapsSearchBodyStrategyType1UnionAllItemType1NorthwestCorner.from_dict(d.pop("northwestCorner"))




        southeast_corner = GoogleMapsSearchBodyStrategyType1UnionAllItemType1SoutheastCorner.from_dict(d.pop("southeastCorner"))




        google_maps_search_body_strategy_type_1_union_all_item_type_1 = cls(
            region_type=region_type,
            northwest_corner=northwest_corner,
            southeast_corner=southeast_corner,
        )


        google_maps_search_body_strategy_type_1_union_all_item_type_1.additional_properties = d
        return google_maps_search_body_strategy_type_1_union_all_item_type_1

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class JobPostingSearchBodySearchParamsIsActiveType2Type1(str, Enum):
    FALSE = "false"
    NO_PREFERENCE = "no_preference"
    TRUE = "true"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsExactCompanyV2Type0AnyOfType0ItemType0Identifier(str, Enum):
    DOMAIN = "domain"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.sync_contact_enrichment_response_200_output_profile_emails_item_status import SyncContactEnrichmentResponse200OutputProfileEmailsItemStatus
from ..models.sync_contact_enrichment_response_200_output_profile_emails_item_type import SyncContactEnrichmentResponse200OutputProfileEmailsItemType
from ..types import UNSET, Unset
from typing import Union






T = TypeVar("T", bound="SyncContactEnrichmentResponse200OutputProfileEmailsItem")



@_attrs_define
class SyncContactEnrichmentResponse200OutputProfileEmailsItem:
    """ 
        Attributes:
            email (str):
            type_ (SyncContactEnrichmentResponse200OutputProfileEmailsItemType):
            status (Union[Unset, SyncContactEnrichmentResponse200OutputProfileEmailsItemStatus]):
     """

    email: str
    type_: SyncContactEnrichmentResponse200OutputProfileEmailsItemType
    status: Union[Unset, SyncContactEnrichmentResponse200OutputProfileEmailsItemStatus] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        email = self.email

        type_ = self.type_.value

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value



        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "email": email,
            "type": type_,
        })
        if status is not UNSET:
            field_dict["status"] = status

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        email = d.pop("email")

        type_ = SyncContactEnrichmentResponse200OutputProfileEmailsItemType(d.pop("type"))




        _status = d.pop("status", UNSET)
        status: Union[Unset, SyncContactEnrichmentResponse200OutputProfileEmailsItemStatus]
        if isinstance(_status,  Unset):
            status = UNSET
        else:
            status = SyncContactEnrichmentResponse200OutputProfileEmailsItemStatus(_status)




        sync_contact_enrichment_response_200_output_profile_emails_item = cls(
            email=email,
            type_=type_,
            status=status,
        )


        sync_contact_enrichment_response_200_output_profile_emails_item.additional_properties = d
        return sync_contact_enrichment_response_200_output_profile_emails_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class TextToCombinedSearchResponse200OutputCompanySearchParamsType0OfficeLocationsV2Type0AnyOfType0ItemType2LocationType0RadiusType1Unit(str, Enum):
    KILOMETERS = "kilometers"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.sync_combined_search_body_company_params_exact_company_v2_type_0_any_of_type_0_item_type_3_identifier import SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3Identifier
from ..models.sync_combined_search_body_company_params_exact_company_v2_type_0_any_of_type_0_item_type_3_source_type_1 import SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType1
from ..models.sync_combined_search_body_company_params_exact_company_v2_type_0_any_of_type_0_item_type_3_source_type_2_type_1 import SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType2Type1
from ..models.sync_combined_search_body_company_params_exact_company_v2_type_0_any_of_type_0_item_type_3_source_type_3_type_1 import SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType3Type1
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3")



@_attrs_define
class SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3:
    """ 
        Attributes:
            identifier (SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3Identifier):
            li_org_id (str):
            linkedin_id (Union[None, Unset, str]):
            preferred_name (Union[None, Unset, str]):
            names (Union[None, Unset, list[str]]):
            linkedin_primary_slug (Union[None, Unset, str]):
            domains (Union[None, Unset, list[str]]):
            logo_url (Union[None, Unset, str]):
            source (Union[None, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType1,
                SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType2Type1,
                SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType3Type1, Unset]):
     """

    identifier: SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3Identifier
    li_org_id: str
    linkedin_id: Union[None, Unset, str] = UNSET
    preferred_name: Union[None, Unset, str] = UNSET
    names: Union[None, Unset, list[str]] = UNSET
    linkedin_primary_slug: Union[None, Unset, str] = UNSET
    domains: Union[None, Unset, list[str]] = UNSET
    logo_url: Union[None, Unset, str] = UNSET
    source: Union[None, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType1, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType2Type1, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType3Type1, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        identifier = self.identifier.value

        li_org_id = self.li_org_id

        linkedin_id: Union[None, Unset, str]
        if isinstance(self.linkedin_id, Unset):
            linkedin_id = UNSET
        else:
            linkedin_id = self.linkedin_id

        preferred_name: Union[None, Unset, str]
        if isinstance(self.preferred_name, Unset):
            preferred_name = UNSET
        else:
            preferred_name = self.preferred_name

        names: Union[None, Unset, list[str]]
        if isinstance(self.names, Unset):
            names = UNSET
        elif isinstance(self.names, list):
            names = self.names


        else:
            names = self.names

        linkedin_primary_slug: Union[None, Unset, str]
        if isinstance(self.linkedin_primary_slug, Unset):
            linkedin_primary_slug = UNSET
        else:
            linkedin_primary_slug = self.linkedin_primary_slug

        domains: Union[None, Unset, list[str]]
        if isinstance(self.domains, Unset):
            domains = UNSET
        elif isinstance(self.domains, list):
            domains = self.domains


        else:
            domains = self.domains

        logo_url: Union[None, Unset, str]
        if isinstance(self.logo_url, Unset):
            logo_url = UNSET
        else:
            logo_url = self.logo_url

        source: Union[None, Unset, str]
        if isinstance(self.source, Unset):
            source = UNSET
        elif isinstance(self.source, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType1):
            source = self.source.value
        elif isinstance(self.source, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType2Type1):
            source = self.source.value
        elif isinstance(self.source, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType3Type1):
            source = self.source.value
        else:
            source = self.source


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "identifier": identifier,
            "li_org_id": li_org_id,
        })
        if linkedin_id is not UNSET:
            field_dict["linkedin_id"] = linkedin_id
        if preferred_name is not UNSET:
            field_dict["preferred_name"] = preferred_name
        if names is not UNSET:
            field_dict["names"] = names
        if linkedin_primary_slug is not UNSET:
            field_dict["linkedin_primary_slug"] = linkedin_primary_slug
        if domains is not UNSET:
            field_dict["domains"] = domains
        if logo_url is not UNSET:
            field_dict["logo_url"] = logo_url
        if source is not UNSET:
            field_dict["source"] = source

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        identifier = SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3Identifier(d.pop("identifier"))




        li_org_id = d.pop("li_org_id")

        def _parse_linkedin_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        linkedin_id = _parse_linkedin_id(d.pop("linkedin_id", UNSET))


        def _parse_preferred_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        preferred_name = _parse_preferred_name(d.pop("preferred_name", UNSET))


        def _parse_names(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                names_type_0 = cast(list[str], data)

                return names_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        names = _parse_names(d.pop("names", UNSET))


        def _parse_linkedin_primary_slug(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        linkedin_primary_slug = _parse_linkedin_primary_slug(d.pop("linkedin_primary_slug", UNSET))


        def _parse_domains(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                domains_type_0 = cast(list[str], data)

                return domains_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        domains = _parse_domains(d.pop("domains", UNSET))


        def _parse_logo_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        logo_url = _parse_logo_url(d.pop("logo_url", UNSET))


        def _parse_source(data: object) -> Union[None, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType1, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType2Type1, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType3Type1, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                source_type_1 = SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType1(data)



                return source_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                source_type_2_type_1 = SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType2Type1(data)



                return source_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                source_type_3_type_1 = SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType3Type1(data)



                return source_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[None, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType1, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType2Type1, SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0AnyOfType0ItemType3SourceType3Type1, Unset], data)

        source = _parse_source(d.pop("source", UNSET))


        sync_combined_search_body_company_params_exact_company_v2_type_0_any_of_type_0_item_type_3 = cls(
            identifier=identifier,
            li_org_id=li_org_id,
            linkedin_id=linkedin_id,
            preferred_name=preferred_name,
            names=names,
            linkedin_primary_slug=linkedin_primary_slug,
            domains=domains,
            logo_url=logo_url,
            source=source,
        )


        sync_combined_search_body_company_params_exact_company_v2_type_0_any_of_type_0_item_type_3.additional_properties = d
        return sync_combined_search_body_company_params_exact_company_v2_type_0_any_of_type_0_item_type_3

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.text_to_company_search_response_200_output_data_item_funding_rounds_type_0_item_round_type_type_1 import TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType1
from ..models.text_to_company_search_response_200_output_data_item_funding_rounds_type_0_item_round_type_type_2_type_1 import TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType2Type1
from ..models.text_to_company_search_response_200_output_data_item_funding_rounds_type_0_item_round_type_type_3_type_1 import TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType3Type1
from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="TextToCompanySearchResponse200OutputDataItemFundingRoundsType0Item")



@_attrs_define
class TextToCompanySearchResponse200OutputDataItemFundingRoundsType0Item:
    """ 
        Attributes:
            round_type (Union[None, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType1,
                TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType2Type1,
                TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType3Type1, Unset]):
            announced_on_date (Union[None, Unset, str]):
            raised_amount_usd (Union[None, Unset, float]):
            post_money_valuation_usd (Union[None, Unset, float]):
     """

    round_type: Union[None, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType1, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType2Type1, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType3Type1, Unset] = UNSET
    announced_on_date: Union[None, Unset, str] = UNSET
    raised_amount_usd: Union[None, Unset, float] = UNSET
    post_money_valuation_usd: Union[None, Unset, float] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        round_type: Union[None, Unset, str]
        if isinstance(self.round_type, Unset):
            round_type = UNSET
        elif isinstance(self.round_type, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType1):
            round_type = self.round_type.value
        elif isinstance(self.round_type, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType2Type1):
            round_type = self.round_type.value
        elif isinstance(self.round_type, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType3Type1):
            round_type = self.round_type.value
        else:
            round_type = self.round_type

        announced_on_date: Union[None, Unset, str]
        if isinstance(self.announced_on_date, Unset):
            announced_on_date = UNSET
        else:
            announced_on_date = self.announced_on_date

        raised_amount_usd: Union[None, Unset, float]
        if isinstance(self.raised_amount_usd, Unset):
            raised_amount_usd = UNSET
        else:
            raised_amount_usd = self.raised_amount_usd

        post_money_valuation_usd: Union[None, Unset, float]
        if isinstance(self.post_money_valuation_usd, Unset):
            post_money_valuation_usd = UNSET
        else:
            post_money_valuation_usd = self.post_money_valuation_usd


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if round_type is not UNSET:
            field_dict["round_type"] = round_type
        if announced_on_date is not UNSET:
            field_dict["announced_on_date"] = announced_on_date
        if raised_amount_usd is not UNSET:
            field_dict["raised_amount_usd"] = raised_amount_usd
        if post_money_valuation_usd is not UNSET:
            field_dict["post_money_valuation_usd"] = post_money_valuation_usd

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_round_type(data: object) -> Union[None, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType1, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType2Type1, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType3Type1, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                round_type_type_1 = TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType1(data)



                return round_type_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                round_type_type_2_type_1 = TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType2Type1(data)



                return round_type_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                round_type_type_3_type_1 = TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType3Type1(data)



                return round_type_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[None, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType1, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType2Type1, TextToCompanySearchResponse200OutputDataItemFundingRoundsType0ItemRoundTypeType3Type1, Unset], data)

        round_type = _parse_round_type(d.pop("round_type", UNSET))


        def _parse_announced_on_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        announced_on_date = _parse_announced_on_date(d.pop("announced_on_date", UNSET))


        def _parse_raised_amount_usd(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        raised_amount_usd = _parse_raised_amount_usd(d.pop("raised_amount_usd", UNSET))


        def _parse_post_money_valuation_usd(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        post_money_valuation_usd = _parse_post_money_valuation_usd(d.pop("post_money_valuation_usd", UNSET))


        text_to_company_search_response_200_output_data_item_funding_rounds_type_0_item = cls(
            round_type=round_type,
            announced_on_date=announced_on_date,
            raised_amount_usd=raised_amount_usd,
            post_money_valuation_usd=post_money_valuation_usd,
        )


        text_to_company_search_response_200_output_data_item_funding_rounds_type_0_item.additional_properties = d
        return text_to_company_search_response_200_output_data_item_funding_rounds_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import Union

if TYPE_CHECKING:
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_job_location_type_stats_type_0_hybrid import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Hybrid
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_job_location_type_stats_type_0_remote import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Remote
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_job_location_type_stats_type_0_on_site import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0OnSite





T = TypeVar("T", bound="PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0")



@_attrs_define
class PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0:
    """ 
        Attributes:
            on_site (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0OnSite]):
            remote (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Remote]):
            hybrid (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Hybrid]):
     """

    on_site: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0OnSite'] = UNSET
    remote: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Remote'] = UNSET
    hybrid: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Hybrid'] = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_job_location_type_stats_type_0_hybrid import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Hybrid
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_job_location_type_stats_type_0_remote import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Remote
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_job_location_type_stats_type_0_on_site import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0OnSite
        on_site: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.on_site, Unset):
            on_site = self.on_site.to_dict()

        remote: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.remote, Unset):
            remote = self.remote.to_dict()

        hybrid: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.hybrid, Unset):
            hybrid = self.hybrid.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if on_site is not UNSET:
            field_dict["On-site"] = on_site
        if remote is not UNSET:
            field_dict["Remote"] = remote
        if hybrid is not UNSET:
            field_dict["Hybrid"] = hybrid

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_job_location_type_stats_type_0_hybrid import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Hybrid
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_job_location_type_stats_type_0_remote import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Remote
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_job_location_type_stats_type_0_on_site import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0OnSite
        d = dict(src_dict)
        _on_site = d.pop("On-site", UNSET)
        on_site: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0OnSite]
        if isinstance(_on_site,  Unset):
            on_site = UNSET
        else:
            on_site = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0OnSite.from_dict(_on_site)




        _remote = d.pop("Remote", UNSET)
        remote: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Remote]
        if isinstance(_remote,  Unset):
            remote = UNSET
        else:
            remote = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Remote.from_dict(_remote)




        _hybrid = d.pop("Hybrid", UNSET)
        hybrid: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Hybrid]
        if isinstance(_hybrid,  Unset):
            hybrid = UNSET
        else:
            hybrid = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0JobLocationTypeStatsType0Hybrid.from_dict(_hybrid)




        poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_job_location_type_stats_type_0 = cls(
            on_site=on_site,
            remote=remote,
            hybrid=hybrid,
        )

        return poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_job_location_type_stats_type_0




from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.job_posting_search_body_search_params_companies_type_0_identifier import JobPostingSearchBodySearchParamsCompaniesType0Identifier
from typing import cast






T = TypeVar("T", bound="JobPostingSearchBodySearchParamsCompaniesType0")



@_attrs_define
class JobPostingSearchBodySearchParamsCompaniesType0:
    """ 
        Attributes:
            identifier (JobPostingSearchBodySearchParamsCompaniesType0Identifier):
            value (list[str]): Array of LinkedIn company slugs (e.g., ['microsoft'])
     """

    identifier: JobPostingSearchBodySearchParamsCompaniesType0Identifier
    value: list[str]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        identifier = self.identifier.value

        value = self.value




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "identifier": identifier,
            "value": value,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        identifier = JobPostingSearchBodySearchParamsCompaniesType0Identifier(d.pop("identifier"))




        value = cast(list[str], d.pop("value"))


        job_posting_search_body_search_params_companies_type_0 = cls(
            identifier=identifier,
            value=value,
        )


        job_posting_search_body_search_params_companies_type_0.additional_properties = d
        return job_posting_search_body_search_params_companies_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
